# Changelog

The format is based on [Keep a Changelog][],
and this project adheres to [Semantic Versioning][].

[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html

## [Unreleased]

### Added

-   pp.merge_big_cell
-   tl.aucell
-   tl.getDEG
-   tl.removeBiasGenes
-   pl.plot_cellbin_gradient
-   pl.plot_cellbin_discrete
-   pl.getDefaultColors
